@@ -20,7 +20,7 @@
 #include "dbusserver.h"
 int
 main() {
-    DBusServer server(0);
+    DBusServer server(0, 0);
     server.listen();
 
     return 0;
