@@ -17,6 +17,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
 */
+#include <stdio.h>
 
 #include "eventlistenerqueue.h"
 #include "event.h"
@@ -72,7 +73,7 @@ void* EventListenerQueue::run(void*)
     while (getState() != Stopping)
     {
         sleep (5);
-        if (STRIGI_MUTEX_TRY_LOCK(&m_mutex))
+        if (STRIGI_MUTEX_TRY_LOCK(&m_mutex) == 0)
         {
             
             if (m_waiting.size() > 0)
@@ -107,21 +108,21 @@ void* EventListenerQueue::run(void*)
             char buff [50];
 
             if (m_processed.size() != m_processedOldCount) {
-                snprintf (buff, 50*sizeof(char), "%i", m_processed.size());
+                snprintf (buff, 50*sizeof(char), "%lu", (unsigned long)m_processed.size());
                 STRIGI_LOG_DEBUG ("strigi.EventListenerQueue.run",
                             string(buff) + " events in \"processed\" queue");
                 m_processedOldCount = m_processed.size();
             }
 
             if (m_toProcess.size() != m_toProcessOldCount) {
-                snprintf (buff, 50*sizeof(char), "%i", m_toProcess.size());
+                snprintf (buff, 50*sizeof(char), "%lu", (unsigned long)m_toProcess.size());
                 STRIGI_LOG_DEBUG ("strigi.EventListenerQueue.run",
                             string(buff) + " events in \"to process\" queue");
                 m_toProcessOldCount = m_toProcess.size();
             }
 
             if (m_waiting.size() != m_waitingOldCount) {
-                snprintf (buff, 50*sizeof(char), "%i", m_waiting.size());
+                snprintf (buff, 50*sizeof(char), "%lu", (unsigned long)m_waiting.size());
                 STRIGI_LOG_DEBUG ("strigi.EventListenerQueue.run",
                                 string(buff) + " events in \"waiting\" queue");
                 m_waitingOldCount = m_waiting.size();
@@ -438,7 +439,7 @@ unsigned int EventListenerQueue::size()
 {
     unsigned int i = 0;
     
-    if (STRIGI_MUTEX_TRY_LOCK (&m_mutex))
+    if (STRIGI_MUTEX_TRY_LOCK (&m_mutex) == 0)
     {
         i = m_toProcess.size();
         STRIGI_MUTEX_UNLOCK (&m_mutex);
@@ -451,7 +452,7 @@ vector <Event*> EventListenerQueue::getEvents()
 {
     vector <Event*> result;
 
-    if (STRIGI_MUTEX_TRY_LOCK (&m_mutex))
+    if (STRIGI_MUTEX_TRY_LOCK (&m_mutex) == 0)
     {
         for (map<string, Event*>::iterator iter = m_toProcess.begin();
              iter != m_toProcess.end(); iter++)
