@@ -21,6 +21,7 @@
 #define POLLINGLISTENER_H
 
 #include "eventlistener.h"
+#include "diranalyzer.h"
 
 #include <map>
 #include <pthread.h>
@@ -29,14 +30,21 @@ class Event;
 
 /**
 * @class PollingListener
-* @brief A simple class that polls periodically the filesystem looking for changes
+* @brief A simple class that periodically polls the filesystem looking for
+* changes.
 *
-* It's used when InotifyListener reaches max user watches limit, all remaining dirs to watch are checked by PollingListener.
-* Update interval is configurable by the user.
+* The polling listener walks through all the subdirectories of the set
+* directories and reports on files that have been modified since the last time
+* the polling was performed.
+*
+* This class is used when inotify is not available on a system or when
+* InotifyListener reaches max user watches limit. All the remaining directories
+* that need to be watched are checked by PollingListener.
+*
+* The update interval is configurable by the user.
 * @sa Filter
 */
-
-class PollingListener : public EventListener {
+class PollingListener : public EventListener, Strigi::AnalysisCaller {
 public:
     PollingListener();
     PollingListener(std::set<std::string>& dirs);
@@ -45,22 +53,20 @@ public:
 
     bool addWatch (const std::string& path);
     void rmWatch (const std::string& path);
-    void addWatches (const std::set<std::string>& watches);
+    void addWatches (const std::set<std::string>& watches,
+                     bool enableInterrupt = false);
     void setIndexedDirectories (const std::set<std::string>& dirs);
 
     void* run(void*);
 
-    static void fileCallback(const char* path, uint dirlen, uint len,
-        time_t mtime);
 private:
     void poll ();
     void clearWatches();
 
-    bool m_firstTime;
-    std::set<std::string> m_watches;
-    std::map<std::string, time_t> m_toIndex;
+    std::vector<std::string> m_watches;
     pthread_mutex_t m_mutex; //!< mutex on m_watches
-    static PollingListener* workingPoller; //!<pointer to current PollingListener instance, used with FileLister's callbacks
+
+    bool continueAnalysis();
 };
 
 #endif
