@@ -17,25 +17,35 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#include "jstreamsconfig.h"
 #include "grepindexwriter.h"
-#include "indexable.h"
+#include "analysisresult.h"
+#include "fieldtypes.h"
+#include <regex.h>
 using namespace std;
 
-GrepIndexWriter::GrepIndexWriter(const char* re) {
-    regcomp(&regex, re, REG_NOSUB);
+class GrepIndexWriter::Private
+{
+public:
+    Private() {}
+    regex_t regex;
+};
+
+GrepIndexWriter::GrepIndexWriter(const char* re)
+  : d(new Private()) {
+    regcomp(&d->regex, re, REG_NOSUB);
 }
 GrepIndexWriter::~GrepIndexWriter() {
-    regfree(&regex);
+    regfree(&d->regex);
+    delete d;
 }
 void
-GrepIndexWriter::startIndexable(jstreams::Indexable* idx) {
+GrepIndexWriter::startAnalysis(const Strigi::AnalysisResult* idx) {
 }
 void
-GrepIndexWriter::finishIndexable(const jstreams::Indexable* idx) {
+GrepIndexWriter::finishAnalysis(const Strigi::AnalysisResult* idx) {
 }
 void
-GrepIndexWriter::addText(const jstreams::Indexable* idx, const char* text,
+GrepIndexWriter::addText(const Strigi::AnalysisResult* idx, const char* text,
         int32_t length) {
     // unfortunately we have to copy the incoming stream because regexec()
     // assumes a null-terminated string and we are not allowed to modify the
@@ -48,23 +58,23 @@ GrepIndexWriter::addText(const jstreams::Indexable* idx, const char* text,
         // look at each line separately
         if (*p == '\n' || *p == '\r') {
             s.assign(start, p-start);
-            if (regexec(&regex, s.c_str(), 0, 0, 0) == 0) {
-                printf("%s:%s\n", idx->getPath().c_str(), s.c_str());
+            if (regexec(&d->regex, s.c_str(), 0, 0, 0) == 0) {
+                printf("%s:%s\n", idx->path().c_str(), s.c_str());
             }
             start = p+1;
         }
         p++;
     }
     s.assign(start, p-start);
-    if (regexec(&regex, s.c_str(), 0, 0, 0) == 0) {
-        printf("%s:%s\n", idx->getPath().c_str(), s.c_str());
+    if (regexec(&d->regex, s.c_str(), 0, 0, 0) == 0) {
+        printf("%s:%s\n", idx->path().c_str(), s.c_str());
     }
 }
 void
-GrepIndexWriter::setField(const jstreams::Indexable* idx,
-        const std::string &fieldname, const std::string& value) {
-    if (regexec(&regex, value.c_str(), 0, 0, 0) == 0) {
-        printf("%s:%s:%s\n", idx->getPath().c_str(), fieldname.c_str(),
-            value.c_str());
+GrepIndexWriter::addValue(const Strigi::AnalysisResult* idx,
+            const Strigi::RegisteredField* field, const std::string& value) {
+    if (regexec(&d->regex, value.c_str(), 0, 0, 0) == 0) {
+        printf("%s:%s:%s\n", idx->path().c_str(),
+            field->key().c_str(), value.c_str());
     }
 }
