@@ -27,6 +27,7 @@
 #include <dirent.h>
 #include <sstream>
 #include <fstream>
+#include <iostream>
 #include <sys/stat.h>
 #include <stdlib.h>
 #include <string.h>
@@ -56,7 +57,9 @@ StrigiHtmlGui::~StrigiHtmlGui() {
 }
 void
 StrigiHtmlGui::printHtmlHeader(ostream& out) {
-    out << "<?xml version='1.0' encoding='utf-8'?>\n"
+    // FIXME: extra spaces added at the beginning as a wordaround because
+    // KIO discards several first chars for unknown reason
+    out << "                           <?xml version='1.0' encoding='utf-8'?>\n"
         "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Strict//EN' "
         "'http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd'>\n"
         "<html xmlns='http://www.w3.org/1999/xhtml'>"
@@ -92,7 +95,8 @@ void
 StrigiHtmlGui::printAbout(ostream& out, const string& path,
         const map<string, string> &params) {
     out << "Strigi v"STRIGI_VERSION_STRING"<br/>";
-    out << "For more details see <a href='http://www.vandenoever.info/software/strigi'>the Strigi Website</a>.";
+    out << "For more details see <a href='http://strigi.sf.net/'>"
+                "the Strigi Website</a>.";
 }
 void
 StrigiHtmlGui::printConfig(ostream& out, const string& path,
@@ -190,12 +194,15 @@ StrigiHtmlGui::printSearch(ostream& out, const string& path,
     if (i != params.end()) {
         max = atoi(i->second.c_str());
     }
-    if (max == 0) max = 10;
+    if (max <= 0 || max > 1000) max = 10;
     int off = 0;
     i = params.find("o");
     if (i != params.end()) {
         off = atoi(i->second.c_str());
     }
+    if (off < 0) {
+        off = 0;
+    }
     string selectedtab;
     i = params.find("t");
     if (i != params.end()) {
@@ -215,20 +222,23 @@ StrigiHtmlGui::printSearch(ostream& out, const string& path,
         bool doother = true;
         tabs = readTabQueries();
         if (tabs.size() == 0) {
-            tabs["Images"] = "content.mime_type:image*";
-            tabs["Mail"] = "content.mime_type:message/*";
-            tabs["Web"] = "content.mime_type:text/html";
-            tabs["Text"] = "content.mime_type:text/*";
+            tabs["Images"] = "mimeType:image*";
+            tabs["Mail"] = "mimeType:message/*";
+            tabs["Web"] = "mimeType:text/html";
+            tabs["Text"] = "mimeType:text/*";
         }
         map<string, string>::const_iterator j;
         string otherq = query;
         for (j = tabs.begin(); j != tabs.end(); ++j) {
-            string q = query+' '+j->second;
+            string q = query;
+            if (q != j->second) {
+                q += ' ' + j->second;
+            }
             int c = p->strigi.countHits(q);
             if (c > 0) {
                 hitcounts[j->first] = c;
                 doother &= c < count;
-        otherq += " -" + j->second;
+                otherq += " -" + j->second;
                 if (j->first == selectedtab || activetab.size() == 0) {
                     activetab = j->first;
                     activequery = q;
@@ -424,9 +434,9 @@ StrigiHtmlGui::Private::printSearchResult(ostream& out,
         icon = "<div class='iconbox'><img class='icon' src='"+icon;
         icon += "'/></div>\n";
     }
-    t = doc.properties.find("audio.title");
+    t = doc.properties.find("title");
     if (t == doc.properties.end()) {
-        t = doc.properties.find("email.subject");
+        t = doc.properties.find("subject");
     }
     size_t l = doc.uri.rfind('/');
     if (t != doc.properties.end()) {
@@ -436,6 +446,7 @@ StrigiHtmlGui::Private::printSearchResult(ostream& out,
     } else {
         name = doc.uri;
     }
+    name = h->escapeString(name);
     if (l != string::npos) {
         folder = doc.uri.substr(0, l);
     }
@@ -465,7 +476,7 @@ StrigiHtmlGui::Private::printSearchResult(ostream& out,
         p = path.find('/', pp);
     }
     subpath = path.substr(pp, path.length()-pp+1);
-    link = h->mapLinkUrl(path);
+    link = h->mapLinkUrl(doc.uri, depth);
     out << "<a href='" << link << "'>" << subpath << "</a>";
 
     out << " - "
