@@ -22,7 +22,6 @@
 
 #include <strigi/strigiconfig.h>
 #include "indexmanager.h"
-//#include "querybitset.h"
 #include <strigi_thread.h>
 #include <string>
 #include <map>
@@ -38,6 +37,9 @@ namespace lucene {
         class IndexWriter;
         class IndexReader;
     }
+    namespace store {
+        class RAMDirectory;
+    }
 }
 
 class CLuceneIndexReader;
@@ -50,13 +52,14 @@ private:
     std::map<STRIGI_THREAD_TYPE, CLuceneIndexReader*> readers;
     CLuceneIndexWriter* writer;
     lucene::index::IndexWriter* indexwriter;
-    //Strigi::QueryBitsetCache bitsets;
     lucene::analysis::Analyzer* analyzer;
     time_t mtime;
     static int numberOfManagers;
 
     void openWriter(bool truncate=false);
 public:
+    lucene::store::RAMDirectory* ramdirectory;
+
     explicit CLuceneIndexManager(const std::string& path);
     ~CLuceneIndexManager();
 
@@ -65,7 +68,6 @@ public:
     Strigi::IndexReader* indexReader();
     Strigi::IndexWriter* indexWriter();
     CLuceneIndexReader* luceneReader();
-//    Strigi::QueryBitsetCache* bitSets();
     int32_t docCount();
     int64_t indexSize();
     void deleteIndex();
@@ -74,7 +76,4 @@ public:
     void setIndexMTime();
 };
 
-CLUCENEINDEXER_EXPORT Strigi::IndexManager*
-createCLuceneIndexManager(const char* path);
-
 #endif
