@@ -39,7 +39,8 @@
 #include <map>
 #include <iostream>
 #include <list>
-#include <string>
+#include <set>
+
 using namespace Strigi;
 using namespace std;
 
@@ -47,8 +48,8 @@ class FieldPropertiesDb::Private {
 public:
     map<string, FieldProperties> properties;
     map<string, ClassProperties> classes;
-    static FieldProperties emptyField;
-    static ClassProperties emptyClass;
+    static const FieldProperties& emptyField();
+    static const ClassProperties& emptyClass();
 
     Private();
     static vector<string> getdirs(const string&);
@@ -94,8 +95,16 @@ public:
 
 };
 
-FieldProperties FieldPropertiesDb::Private::emptyField;
-ClassProperties FieldPropertiesDb::Private::emptyClass;
+const FieldProperties&
+FieldPropertiesDb::Private::emptyField() {
+    static const FieldProperties e;
+    return e;
+}
+const ClassProperties&
+FieldPropertiesDb::Private::emptyClass() {
+    static const ClassProperties f;
+    return f;
+}
 
 FieldPropertiesDb&
 FieldPropertiesDb::db() {
@@ -112,7 +121,7 @@ FieldPropertiesDb::properties(const std::string& uri) const {
     map<std::string, FieldProperties>::const_iterator j
         = p->properties.find(uri);
     if (j == p->properties.end()) {
-        return FieldPropertiesDb::Private::emptyField;
+        return FieldPropertiesDb::Private::emptyField();
     } else {
         return j->second;
     }
@@ -126,7 +135,7 @@ const ClassProperties&
 FieldPropertiesDb::classes(const std::string& uri) const {
     map<std::string, ClassProperties>::const_iterator j = p->classes.find(uri);
     if (j == p->classes.end()) {
-        return FieldPropertiesDb::Private::emptyClass;
+        return FieldPropertiesDb::Private::emptyClass();
     } else {
         return j->second;
     }
@@ -178,8 +187,12 @@ FieldPropertiesDb::Private::Private() {
 
     vector<string> dirs = getXdgDirs();
     vector<string>::const_iterator i;
+    set<string> done;
     for (i=dirs.begin(); i!=dirs.end(); i++) {
-        loadProperties(*i);
+        if (done.find(*i) == done.end()) {
+            done.insert(*i);
+            loadProperties(*i);
+        }
     }
 
     // Generate childUris, applicable* and locales values.
@@ -255,6 +268,9 @@ FieldPropertiesDb::Private::addEssentialProperties() {
     props.uri = FieldRegister::filenameFieldName;
     properties[FieldRegister::filenameFieldName] = props;
 
+    props.uri = FieldRegister::mimetypeFieldName;
+    properties[FieldRegister::mimetypeFieldName] = props;
+
     props.uri = FieldRegister::parentLocationFieldName;
     props.tokenized = false;
     properties[FieldRegister::parentLocationFieldName] = props;
@@ -263,13 +279,23 @@ void
 FieldPropertiesDb::Private::loadProperties(const string& dir) {
     string pdir = dir + "/strigi/fieldproperties/";
     DIR* d = opendir(pdir.c_str());
-    if (!d) return;
+    if (!d) {
+        pdir = dir;
+        d = opendir(pdir.c_str());
+    }
+    if (!d) {
+        return;
+    }
+    if (pdir[pdir.length()-1] != '/') {
+        pdir.append("/");
+    }
     struct dirent* de = readdir(d);
     struct stat s;
     char* data = 0;
     while (de) {
         string path(pdir+de->d_name);
-        if (!stat(path.c_str(), &s) && S_ISREG(s.st_mode)) {
+        if (path.length() >= 5 && path.substr(path.length()-5) == ".rdfs" &&
+                !stat(path.c_str(), &s) && S_ISREG(s.st_mode)) {
             FILE* f = fopen(path.c_str(), "r");
             if (f) {
                 // read the entire file at once
