@@ -120,7 +120,19 @@ parse(const char* p, Query& q) {
     }
     return space+1;
 }
-
+void
+prependXesamNamespace(Query& query) {
+    // prepend the field names with the xesam namespace
+    // this will be elaborated once the xesam spec continues
+    vector<string>::iterator end(query.fields().end());
+    for (vector<string>::iterator i = query.fields().begin(); i != end; ++i) {
+        *i = "http://freedesktop.org/standards/xesam/1.0/core#" + *i;
+    }
+    std::vector<Query>::iterator qend(query.subQueries().end());
+    for (vector<Query>::iterator i = query.subQueries().begin(); i!=qend; ++i) {
+        prependXesamNamespace(*i);
+    }
+}
 Query
 QueryParser::buildQuery(const std::string& q) {
     Query query;
@@ -140,14 +152,7 @@ QueryParser::buildQuery(const std::string& q) {
         Query q = query.subQueries()[0];
         query = q;
     }
+    prependXesamNamespace(query);
 
-    // prepend the field names with the xesam namespace
-    // this will be elaborated once the xesam spec continues
-    vector<string>::iterator end(query.fields().end());
-    for (vector<string>::iterator i = query.fields().begin(); i != end; ++i) {
-         *i = "http://freedesktop.org/standards/xesam/1.0/core#" + *i;
-    }
-    //cerr << "query: '" << q << "' : " << query.subQueries().size() << "'"
-    //    << query.term().string() << "'" << endl;
     return query;
 }
