@@ -17,6 +17,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
+#include <algorithm>
 #include "kmpsearcher.h"
 #include <strigi/strigiconfig.h>
 
@@ -42,7 +43,8 @@ preBmBc(const char* x, int32_t m, int32_t* bmBc) {
 void
 suffixes(const char* x, int32_t m, int32_t* suff) {
     int32_t f, g, i;
- 
+
+    f = 0; 
     suff[m - 1] = m;
     g = m - 1;
     for (i = m - 2; i >= 0; --i) {
