@@ -20,10 +20,11 @@
 #include "../fileinputstream.h"
 #include "../bz2inputstream.h"
 #include "inputstreamtests.h"
-using namespace jstreams;
+
+using namespace Strigi;
 
 int
-BZ2InputStreamTest(int argc, char** argv) {
+BZ2InputStreamTest(int argc, char* argv[]) {
     if (argc < 2) return 0;
     VERIFY(chdir(argv[1]) == 0);
 
